# SWGScreenshotApi

All URIs are relative to *https://api.browshot.com/api/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**screenshotCreateGet**](SWGScreenshotApi.md#screenshotcreateget) | **GET** /screenshot/create | Request a screenshot
[**screenshotDeleteGet**](SWGScreenshotApi.md#screenshotdeleteget) | **GET** /screenshot/delete | Delete screenshot data
[**screenshotHostGet**](SWGScreenshotApi.md#screenshothostget) | **GET** /screenshot/host | Host thumbnails on your own S3 account or on Browshot.
[**screenshotHtmlGet**](SWGScreenshotApi.md#screenshothtmlget) | **GET** /screenshot/html | Get the HTML code
[**screenshotInfoGet**](SWGScreenshotApi.md#screenshotinfoget) | **GET** /screenshot/info | Query screenshot status
[**screenshotListGet**](SWGScreenshotApi.md#screenshotlistget) | **GET** /screenshot/list | Get information about the last 100 screenshots requested.
[**screenshotMultipleGet**](SWGScreenshotApi.md#screenshotmultipleget) | **GET** /screenshot/multiple | Request multiple screenshots
[**screenshotSearchGet**](SWGScreenshotApi.md#screenshotsearchget) | **GET** /screenshot/search | Search for screenshots of a specific URL.
[**screenshotShareGet**](SWGScreenshotApi.md#screenshotshareget) | **GET** /screenshot/share | Share a screenshot
[**screenshotThumbnailGet**](SWGScreenshotApi.md#screenshotthumbnailget) | **GET** /screenshot/thumbnail | Retrieve a thumbnail image


# **screenshotCreateGet**
```objc
-(NSNumber*) screenshotCreateGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    shots: (NSNumber*) shots
    shotInterval: (NSNumber*) shotInterval
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
        completionHandler: (void (^)(SWGScreenshot* output, NSError* error)) handler;
```

Request a screenshot

Screenshots requests to private and shared instances require a positive balance.  *IMPORTANT*: Remember that you can only do 100 free screenshots per month. To used a premium instance, use instance_id=65 for example. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSString* url = @"url_example"; // URL of the page to get a screenshot for
NSNumber* instanceId = @56; // instance ID to use
NSString* size = @"screen"; // screenshot size - \"screen\" (default) or \"page\" (optional) (default to screen)
NSNumber* cache = @86400; // use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional) (default to 86400)
NSNumber* delay = @5; // number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional) (default to 5)
NSNumber* flashDelay = @10; // number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional) (default to 10)
NSNumber* screenWidth = @1024; // width of the browser window. For desktop browsers only. (optional) (default to 1024)
NSNumber* screenHeight = @768; // height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional) (default to 768)
NSNumber* priority = @56; // assign priority to the screenshot (for private instances only) (optional)
NSString* referer = @"referer_example"; // use a custom referrer header - paid screenshots only (optional)
NSString* postData = @"postData_example"; // send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
NSString* cookie = @"cookie_example"; // set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
NSString* script = @"script_example"; // URL of javascript file to execute after the page load event (optional)
NSNumber* details = @2; // level of information available with screenshot/info (optional) (default to 2)
NSNumber* html = @0; // saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional) (default to 0)
NSNumber* maxWait = @0; // maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional) (default to 0)
NSString* headers = @"headers_example"; // any custom HTTP headers. (Not supported with Internet Explorer) (optional)
NSNumber* shots = @1; // take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots. (optional) (default to 1)
NSNumber* shotInterval = @5; // number of seconds between 2 screenshots (optional) (default to 5)
NSString* hosting = @"hosting_example"; // hosting option - s3 or browshot (optional)
NSNumber* hostingHeight = @56; // maximum height of the thumbnail to host (optional)
NSNumber* hostingWidth = @56; // maximum height of the thumbnail to host (optional)
NSNumber* hostingScale = @1; // scale of the thumbnail to host (optional) (default to 1)
NSString* hostingBucket = @"hostingBucket_example"; // S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
NSString* hostingFile = @"hostingFile_example"; // file name to use (for S3 only) (optional)
NSString* hostingHeaders = @"hostingHeaders_example"; // list of headers to add to the S3 object (for S3 only) (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Request a screenshot
[apiInstance screenshotCreateGetWithUrl:url
              instanceId:instanceId
              size:size
              cache:cache
              delay:delay
              flashDelay:flashDelay
              screenWidth:screenWidth
              screenHeight:screenHeight
              priority:priority
              referer:referer
              postData:postData
              cookie:cookie
              script:script
              details:details
              html:html
              maxWait:maxWait
              headers:headers
              shots:shots
              shotInterval:shotInterval
              hosting:hosting
              hostingHeight:hostingHeight
              hostingWidth:hostingWidth
              hostingScale:hostingScale
              hostingBucket:hostingBucket
              hostingFile:hostingFile
              hostingHeaders:hostingHeaders
          completionHandler: ^(SWGScreenshot* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotCreateGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **NSString***| URL of the page to get a screenshot for | 
 **instanceId** | **NSNumber***| instance ID to use | 
 **size** | **NSString***| screenshot size - \&quot;screen\&quot; (default) or \&quot;page\&quot; | [optional] [default to screen]
 **cache** | **NSNumber***| use a previous screenshot (same URL, same instance) if it was done within &lt;cache_value&gt; seconds. The default value is 24hours. Specify cache&#x3D;0 if you want a new screenshot. | [optional] [default to 86400]
 **delay** | **NSNumber***| number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay&#x3D;0 to take screenshots faster. | [optional] [default to 5]
 **flashDelay** | **NSNumber***| number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay&#x3D;0 to take screenshots faster. | [optional] [default to 10]
 **screenWidth** | **NSNumber***| width of the browser window. For desktop browsers only. | [optional] [default to 1024]
 **screenHeight** | **NSNumber***| height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) | [optional] [default to 768]
 **priority** | **NSNumber***| assign priority to the screenshot (for private instances only) | [optional] 
 **referer** | **NSString***| use a custom referrer header - paid screenshots only | [optional] 
 **postData** | **NSString***| send a POST requests with post_data, useful for filling out forms - paid screenshots only | [optional] 
 **cookie** | **NSString***| set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only | [optional] 
 **script** | **NSString***| URL of javascript file to execute after the page load event | [optional] 
 **details** | **NSNumber***| level of information available with screenshot/info | [optional] [default to 2]
 **html** | **NSNumber***| saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. | [optional] [default to 0]
 **maxWait** | **NSNumber***| maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 &#x3D; disabled) | [optional] [default to 0]
 **headers** | **NSString***| any custom HTTP headers. (Not supported with Internet Explorer) | [optional] 
 **shots** | **NSNumber***| take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots. | [optional] [default to 1]
 **shotInterval** | **NSNumber***| number of seconds between 2 screenshots | [optional] [default to 5]
 **hosting** | **NSString***| hosting option - s3 or browshot | [optional] 
 **hostingHeight** | **NSNumber***| maximum height of the thumbnail to host | [optional] 
 **hostingWidth** | **NSNumber***| maximum height of the thumbnail to host | [optional] 
 **hostingScale** | **NSNumber***| scale of the thumbnail to host | [optional] [default to 1]
 **hostingBucket** | **NSString***| S3 bucket to upload the screenshot or thumbnail (required for S3) | [optional] 
 **hostingFile** | **NSString***| file name to use (for S3 only) | [optional] 
 **hostingHeaders** | **NSString***| list of headers to add to the S3 object (for S3 only) | [optional] 

### Return type

[**SWGScreenshot***](SWGScreenshot.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotDeleteGet**
```objc
-(NSNumber*) screenshotDeleteGetWithId: (NSNumber*) _id
    data: (NSString*) data
        completionHandler: (void (^)(NSArray<SWGScreenshotShort>* output, NSError* error)) handler;
```

Delete screenshot data

You can delete details of your screenshots to remove any confidential information. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID
NSString* data = @"image"; // data to remove. You can specify multiple of them (separated by a ,): *image* (image files), *url* (url requested), *metadata* (time added, time finished, post data, cookie and referer used for the screenshot), *all* (all data and files)  (optional) (default to image)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Delete screenshot data
[apiInstance screenshotDeleteGetWithId:_id
              data:data
          completionHandler: ^(NSArray<SWGScreenshotShort>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotDeleteGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID | 
 **data** | **NSString***| data to remove. You can specify multiple of them (separated by a ,): *image* (image files), *url* (url requested), *metadata* (time added, time finished, post data, cookie and referer used for the screenshot), *all* (all data and files)  | [optional] [default to image]

### Return type

[**NSArray<SWGScreenshotShort>***](SWGScreenshotShort.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotHostGet**
```objc
-(NSNumber*) screenshotHostGetWithId: (NSNumber*) _id
    hosting: (NSString*) hosting
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    bucket: (NSString*) bucket
    file: (NSString*) file
    headers: (NSString*) headers
        completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler;
```

Host thumbnails on your own S3 account or on Browshot.

You can host screenshots and thumbnails on your own S3 account or on Browshot.

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID
NSString* hosting = @"hosting_example"; // hosting option: s3 or browshot
NSNumber* width = @56; // width of the thumbnail (optional)
NSNumber* height = @56; // height of the thumbnail (optional)
NSNumber* scale = @1; // scale of the thumbnail (optional) (default to 1)
NSString* bucket = @"bucket_example"; // S3 bucket to upload the screenshot or thumbnail - required with hosting=s3 (optional)
NSString* file = @"file_example"; // file name to use - optional, used with hosting=s3 (optional)
NSString* headers = @"headers_example"; // HTTP headers to add to your S3 object - optional, used with hosting=s3 (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Host thumbnails on your own S3 account or on Browshot.
[apiInstance screenshotHostGetWithId:_id
              hosting:hosting
              width:width
              height:height
              scale:scale
              bucket:bucket
              file:file
              headers:headers
          completionHandler: ^(NSArray<SWGScreenshotHost>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotHostGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID | 
 **hosting** | **NSString***| hosting option: s3 or browshot | 
 **width** | **NSNumber***| width of the thumbnail | [optional] 
 **height** | **NSNumber***| height of the thumbnail | [optional] 
 **scale** | **NSNumber***| scale of the thumbnail | [optional] [default to 1]
 **bucket** | **NSString***| S3 bucket to upload the screenshot or thumbnail - required with hosting&#x3D;s3 | [optional] 
 **file** | **NSString***| file name to use - optional, used with hosting&#x3D;s3 | [optional] 
 **headers** | **NSString***| HTTP headers to add to your S3 object - optional, used with hosting&#x3D;s3 | [optional] 

### Return type

[**NSArray<SWGScreenshotHost>***](SWGScreenshotHost.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotHtmlGet**
```objc
-(NSNumber*) screenshotHtmlGetWithId: (NSNumber*) _id
        completionHandler: (void (^)(NSError* error)) handler;
```

Get the HTML code

Retrieve the HTML code of the rendered page. This API call should be used when html=1 was specified in the screenshot request. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Get the HTML code
[apiInstance screenshotHtmlGetWithId:_id
          completionHandler: ^(NSError* error) {
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotHtmlGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID | 

### Return type

void (empty response body)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: text/html

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotInfoGet**
```objc
-(NSNumber*) screenshotInfoGetWithId: (NSNumber*) _id
    details: (NSNumber*) details
        completionHandler: (void (^)(NSArray<SWGScreenshot>* output, NSError* error)) handler;
```

Query screenshot status

Once a screenshot has been requested, its status must be checked until it is either \"error\" or \"finished\".

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID received from /api/v1/screenshot/create
NSNumber* details = @2; // level of details about the screenshot and the page (optional) (default to 2)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Query screenshot status
[apiInstance screenshotInfoGetWithId:_id
              details:details
          completionHandler: ^(NSArray<SWGScreenshot>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotInfoGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID received from /api/v1/screenshot/create | 
 **details** | **NSNumber***| level of details about the screenshot and the page | [optional] [default to 2]

### Return type

[**NSArray<SWGScreenshot>***](SWGScreenshot.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotListGet**
```objc
-(NSNumber*) screenshotListGetWithLimit: (NSNumber*) limit
    status: (NSString*) status
        completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler;
```

Get information about the last 100 screenshots requested.

Get information about the last 100 screenshots requested.

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* limit = @100; // maximum number of screenshots' information to return (optional) (default to 100)
NSString* status = @"status_example"; // get list of screenshot in a given status (error, finished, in_process) (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Get information about the last 100 screenshots requested.
[apiInstance screenshotListGetWithLimit:limit
              status:status
          completionHandler: ^(NSArray<SWGScreenshotList>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotListGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **NSNumber***| maximum number of screenshots&#39; information to return | [optional] [default to 100]
 **status** | **NSString***| get list of screenshot in a given status (error, finished, in_process) | [optional] 

### Return type

[**NSArray<SWGScreenshotList>***](SWGScreenshotList.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotMultipleGet**
```objc
-(NSNumber*) screenshotMultipleGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
        completionHandler: (void (^)(SWGScreenshotList* output, NSError* error)) handler;
```

Request multiple screenshots

Request multiple screenshots in one API call. The API call accepts all the parameters supported by screenshot/create. You can specify up to 10 URLs and 10 instances for a total of 100 screenshots in one API call. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSString* url = @"url_example"; // URL of the page to get a screenshot for. You can specify multiple url parameters (up to 10).
NSNumber* instanceId = @56; // instance ID to use. You can specify multiple instance_id parameters (up to 10).
NSString* size = @"screen"; // screenshot size - \"screen\" (default) or \"page\" (optional) (default to screen)
NSNumber* cache = @86400; // use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional) (default to 86400)
NSNumber* delay = @5; // number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional) (default to 5)
NSNumber* flashDelay = @10; // number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional) (default to 10)
NSNumber* screenWidth = @1024; // width of the browser window. For desktop browsers only. (optional) (default to 1024)
NSNumber* screenHeight = @768; // height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional) (default to 768)
NSNumber* priority = @56; // assign priority to the screenshot (for private instances only) (optional)
NSString* referer = @"referer_example"; // use a custom referrer header - paid screenshots only (optional)
NSString* postData = @"postData_example"; // send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
NSString* cookie = @"cookie_example"; // set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
NSString* script = @"script_example"; // URL of javascript file to execute after the page load event (optional)
NSNumber* details = @2; // level of information available with screenshot/info (optional) (default to 2)
NSNumber* html = @0; // saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional) (default to 0)
NSNumber* maxWait = @0; // maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional) (default to 0)
NSString* headers = @"headers_example"; // any custom HTTP headers. (Not supported with Internet Explorer) (optional)
NSString* hosting = @"hosting_example"; // hosting option - s3 or browshot (optional)
NSNumber* hostingHeight = @56; // maximum height of the thumbnail to host (optional)
NSNumber* hostingWidth = @56; // maximum height of the thumbnail to host (optional)
NSNumber* hostingScale = @1; // scale of the thumbnail to host (optional) (default to 1)
NSString* hostingBucket = @"hostingBucket_example"; // S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
NSString* hostingFile = @"hostingFile_example"; // file name to use (for S3 only) (optional)
NSString* hostingHeaders = @"hostingHeaders_example"; // list of headers to add to the S3 object (for S3 only) (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Request multiple screenshots
[apiInstance screenshotMultipleGetWithUrl:url
              instanceId:instanceId
              size:size
              cache:cache
              delay:delay
              flashDelay:flashDelay
              screenWidth:screenWidth
              screenHeight:screenHeight
              priority:priority
              referer:referer
              postData:postData
              cookie:cookie
              script:script
              details:details
              html:html
              maxWait:maxWait
              headers:headers
              hosting:hosting
              hostingHeight:hostingHeight
              hostingWidth:hostingWidth
              hostingScale:hostingScale
              hostingBucket:hostingBucket
              hostingFile:hostingFile
              hostingHeaders:hostingHeaders
          completionHandler: ^(SWGScreenshotList* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotMultipleGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **NSString***| URL of the page to get a screenshot for. You can specify multiple url parameters (up to 10). | 
 **instanceId** | **NSNumber***| instance ID to use. You can specify multiple instance_id parameters (up to 10). | 
 **size** | **NSString***| screenshot size - \&quot;screen\&quot; (default) or \&quot;page\&quot; | [optional] [default to screen]
 **cache** | **NSNumber***| use a previous screenshot (same URL, same instance) if it was done within &lt;cache_value&gt; seconds. The default value is 24hours. Specify cache&#x3D;0 if you want a new screenshot. | [optional] [default to 86400]
 **delay** | **NSNumber***| number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay&#x3D;0 to take screenshots faster. | [optional] [default to 5]
 **flashDelay** | **NSNumber***| number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay&#x3D;0 to take screenshots faster. | [optional] [default to 10]
 **screenWidth** | **NSNumber***| width of the browser window. For desktop browsers only. | [optional] [default to 1024]
 **screenHeight** | **NSNumber***| height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) | [optional] [default to 768]
 **priority** | **NSNumber***| assign priority to the screenshot (for private instances only) | [optional] 
 **referer** | **NSString***| use a custom referrer header - paid screenshots only | [optional] 
 **postData** | **NSString***| send a POST requests with post_data, useful for filling out forms - paid screenshots only | [optional] 
 **cookie** | **NSString***| set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only | [optional] 
 **script** | **NSString***| URL of javascript file to execute after the page load event | [optional] 
 **details** | **NSNumber***| level of information available with screenshot/info | [optional] [default to 2]
 **html** | **NSNumber***| saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. | [optional] [default to 0]
 **maxWait** | **NSNumber***| maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 &#x3D; disabled) | [optional] [default to 0]
 **headers** | **NSString***| any custom HTTP headers. (Not supported with Internet Explorer) | [optional] 
 **hosting** | **NSString***| hosting option - s3 or browshot | [optional] 
 **hostingHeight** | **NSNumber***| maximum height of the thumbnail to host | [optional] 
 **hostingWidth** | **NSNumber***| maximum height of the thumbnail to host | [optional] 
 **hostingScale** | **NSNumber***| scale of the thumbnail to host | [optional] [default to 1]
 **hostingBucket** | **NSString***| S3 bucket to upload the screenshot or thumbnail (required for S3) | [optional] 
 **hostingFile** | **NSString***| file name to use (for S3 only) | [optional] 
 **hostingHeaders** | **NSString***| list of headers to add to the S3 object (for S3 only) | [optional] 

### Return type

[**SWGScreenshotList***](SWGScreenshotList.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotSearchGet**
```objc
-(NSNumber*) screenshotSearchGetWithUrl: (NSString*) url
    limit: (NSNumber*) limit
    status: (NSString*) status
        completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler;
```

Search for screenshots of a specific URL.

Search for screenshots of a specific URL.

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSString* url = @"url_example"; // look for a string matching the URL requested
NSNumber* limit = @50; // maximum number of screenshots' information to return (optional) (default to 50)
NSString* status = @"status_example"; // get list of screenshot in a given status (error, finished, in_process) (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Search for screenshots of a specific URL.
[apiInstance screenshotSearchGetWithUrl:url
              limit:limit
              status:status
          completionHandler: ^(NSArray<SWGScreenshotList>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotSearchGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **NSString***| look for a string matching the URL requested | 
 **limit** | **NSNumber***| maximum number of screenshots&#39; information to return | [optional] [default to 50]
 **status** | **NSString***| get list of screenshot in a given status (error, finished, in_process) | [optional] 

### Return type

[**NSArray<SWGScreenshotList>***](SWGScreenshotList.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotShareGet**
```objc
-(NSNumber*) screenshotShareGetWithId: (NSNumber*) _id
    note: (NSString*) note
        completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler;
```

Share a screenshot

You can make your screenshots public, add notes, and share it with your friends and colleagues. Only screenshots which are successfully completed can be shared.n the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID
NSString* note = @"note_example"; // note to add on the sharing page (optional)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Share a screenshot
[apiInstance screenshotShareGetWithId:_id
              note:note
          completionHandler: ^(NSArray<SWGScreenshotHost>* output, NSError* error) {
                        if (output) {
                            NSLog(@"%@", output);
                        }
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotShareGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID | 
 **note** | **NSString***| note to add on the sharing page | [optional] 

### Return type

[**NSArray<SWGScreenshotHost>***](SWGScreenshotHost.md)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **screenshotThumbnailGet**
```objc
-(NSNumber*) screenshotThumbnailGetWithId: (NSNumber*) _id
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    zoom: (NSNumber*) zoom
    ratio: (NSString*) ratio
    left: (NSNumber*) left
    right: (NSNumber*) right
    top: (NSNumber*) top
    bottom: (NSNumber*) bottom
    format: (NSString*) format
    shot: (NSNumber*) shot
    quality: (NSNumber*) quality
        completionHandler: (void (^)(NSError* error)) handler;
```

Retrieve a thumbnail image

Unlike the other API calls, this API sends back the thumbnail as a PNG file, not JSON. The HTTP response code indicates whether the screenshot was successful (200), or incomplete (404) or failed (404). If the screenshot failed or is not finished, a default image \"Not found\" is sent.  You can crop your screenshots. The crop is done first, then the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 

### Example 
```objc
SWGConfiguration *apiConfig = [SWGConfiguration sharedConfig];

// Configure API key authorization: (authentication scheme: apiKeyQuery)
[apiConfig setApiKey:@"YOUR_API_KEY" forApiKeyIdentifier:@"key"];
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//[apiConfig setApiKeyPrefix:@"Bearer" forApiKeyIdentifier:@"key"];


NSNumber* _id = @56; // screenshot ID
NSNumber* width = @56; // width of the thumbnail (optional)
NSNumber* height = @56; // height of the thumbnail (optional)
NSNumber* scale = @1; // scale of the thumbnail (optional) (default to 1)
NSNumber* zoom = @100; // zoom 1 to 100 percent (optional) (default to 100)
NSString* ratio = @"fit"; // Use fit to keep the original page ration, and fill to get a thumbnail for the exact width and height.  specified. If you provide both width and height, you need to specify the ratio: fit to keep the original width/height ratio (the thumbnail might be smaller than the specified width and height), or fill to crop the image if necessary. (optional) (default to fit)
NSNumber* left = @0; // left edge of the area to be cropped (optional) (default to 0)
NSNumber* right = @0; // right edge of the area to be cropped (optional) (default to 0)
NSNumber* top = @0; // top edge of the area to be cropped (optional) (default to 0)
NSNumber* bottom = @56; // bottom edge of the area to be cropped (optional)
NSString* format = @"png"; // image as PNG or JPEG (optional) (default to png)
NSNumber* shot = @1; // get the second or third screenshot if multiple screenshots were requested (optional) (default to 1)
NSNumber* quality = @100; // JPEG quality factor (for JPEG thumbnails only) (optional) (default to 100)

SWGScreenshotApi*apiInstance = [[SWGScreenshotApi alloc] init];

// Retrieve a thumbnail image
[apiInstance screenshotThumbnailGetWithId:_id
              width:width
              height:height
              scale:scale
              zoom:zoom
              ratio:ratio
              left:left
              right:right
              top:top
              bottom:bottom
              format:format
              shot:shot
              quality:quality
          completionHandler: ^(NSError* error) {
                        if (error) {
                            NSLog(@"Error calling SWGScreenshotApi->screenshotThumbnailGet: %@", error);
                        }
                    }];
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **_id** | **NSNumber***| screenshot ID | 
 **width** | **NSNumber***| width of the thumbnail | [optional] 
 **height** | **NSNumber***| height of the thumbnail | [optional] 
 **scale** | **NSNumber***| scale of the thumbnail | [optional] [default to 1]
 **zoom** | **NSNumber***| zoom 1 to 100 percent | [optional] [default to 100]
 **ratio** | **NSString***| Use fit to keep the original page ration, and fill to get a thumbnail for the exact width and height.  specified. If you provide both width and height, you need to specify the ratio: fit to keep the original width/height ratio (the thumbnail might be smaller than the specified width and height), or fill to crop the image if necessary. | [optional] [default to fit]
 **left** | **NSNumber***| left edge of the area to be cropped | [optional] [default to 0]
 **right** | **NSNumber***| right edge of the area to be cropped | [optional] [default to 0]
 **top** | **NSNumber***| top edge of the area to be cropped | [optional] [default to 0]
 **bottom** | **NSNumber***| bottom edge of the area to be cropped | [optional] 
 **format** | **NSString***| image as PNG or JPEG | [optional] [default to png]
 **shot** | **NSNumber***| get the second or third screenshot if multiple screenshots were requested | [optional] [default to 1]
 **quality** | **NSNumber***| JPEG quality factor (for JPEG thumbnails only) | [optional] [default to 100]

### Return type

void (empty response body)

### Authorization

[apiKeyQuery](../README.md#apiKeyQuery)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: image/png, image/jpeg

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

